@@ -30,8 +30,8 @@ signature_multi_precision_integer(int pub, int skip)
 		break;
 	case 16:
 	case 20:
-		multi_precision_integer("ElGamal ?");
-		multi_precision_integer("ElGamal ?");
+		multi_precision_integer("ElGamal a = g^k mod p");
+		multi_precision_integer("ElGamal b = (h - a*x)/k mod p - 1");
 		break;
 	case 17:
 		multi_precision_integer("DSA r");
@@ -163,9 +163,11 @@ new_Signature_Packet(int len)
 	pub = Getc();
 	pub_algs(pub);
 	hash_algs(Getc());
-	hsplen = Getc() * 256 + Getc();
+	hsplen = Getc() * 256;
+	hsplen += Getc();
 	parse_subpacket("Hashed Sub", hsplen);
-	usplen = Getc() * 256 + Getc();	
+	usplen = Getc() * 256;
+	usplen += Getc();	
 	parse_subpacket("Sub", usplen);
 	hash2();
 	signature_multi_precision_integer(pub, len - 9 - hsplen - usplen);
